@@ -135,10 +135,126 @@ user_combobox_changed (GtkComboBox *widget,
     }
 }
 
+#if HAVE_ACCOUNTSSERVICE
+static GdkPixbuf *
+get_user_icon (char *username)
+{
+  GError *error;
+  GDBusConnection *connection;
+  GVariant *find_user_result;
+  GVariant *get_icon_result;
+  GVariant *icon_result_variant;
+  const gchar *user_path;
+  const gchar *icon_filename;
+  GdkPixbuf *pixbuf = NULL;
+
+  error = NULL;
+  connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
+
+  if (connection == NULL)
+    {
+      g_warning ("Unable to connect to system bus: %s", error->message);
+      g_error_free (error);
+      return NULL;
+    }
+
+  find_user_result = g_dbus_connection_call_sync (connection,
+                                          "org.freedesktop.Accounts",
+                                          "/org/freedesktop/Accounts",
+                                          "org.freedesktop.Accounts",
+                                          "FindUserByName",
+                                          g_variant_new ("(s)",
+                                          username),
+                                          G_VARIANT_TYPE ("(o)"),
+                                          G_DBUS_CALL_FLAGS_NONE,
+                                          -1,
+                                          NULL,
+                                          &error);
+
+  if (find_user_result == NULL)
+    {
+      g_warning ("Accounts couldn't find user: %s", error->message);
+      g_error_free (error);
+      return NULL;
+    }
+
+  user_path = g_variant_get_string (g_variant_get_child_value (find_user_result, 0),
+                                    NULL);
+
+  get_icon_result = g_dbus_connection_call_sync (connection,
+                                                 "org.freedesktop.Accounts",
+                                                 user_path,
+                                                 "org.freedesktop.DBus.Properties",
+                                                 "Get",
+                                                 g_variant_new ("(ss)",
+                                                                "org.freedesktop.Accounts.User",
+                                                                "IconFile"),
+                                                 G_VARIANT_TYPE ("(v)"),
+                                                 G_DBUS_CALL_FLAGS_NONE,
+                                                 -1,
+                                                 NULL,
+                                                 &error);
+
+  g_variant_unref (find_user_result);
+
+  if (get_icon_result == NULL)
+    {
+      g_warning ("Accounts couldn't find user icon: %s", error->message);
+      g_error_free (error);
+      return NULL;
+    }
+
+  g_variant_get_child (get_icon_result, 0, "v", &icon_result_variant);
+  icon_filename = g_variant_get_string (icon_result_variant, NULL);
+
+  if (icon_filename == NULL)
+    {
+      g_warning ("Accounts didn't return a valid filename for user icon");
+    }
+  else
+    {
+      /* TODO: we probably shouldn't hard-code the size to 16x16 */
+      pixbuf = gdk_pixbuf_new_from_file_at_size (icon_filename,
+                                                 16,
+                                                 16,
+                                                 &error);
+      if (pixbuf == NULL)
+        {
+          g_warning ("Couldn't open user icon: %s", error->message);
+          g_error_free (error);
+        }
+    }
+
+  g_variant_unref (icon_result_variant);
+  g_variant_unref (get_icon_result);
+
+  return pixbuf;
+}
+#else
+static GdkPixbuf *
+get_user_icon (char *username)
+{
+  GdkPixbuf *pixbuf = NULL;
+  struct passwd *passwd;
+
+  passwd = getpwnam (username);
+  if (passwd->pw_dir != NULL)
+    {
+      gchar *path;
+      path = g_strdup_printf ("%s/.face", passwd->pw_dir);
+      /* TODO: we probably shouldn't hard-code the size to 16x16 */
+      pixbuf = gdk_pixbuf_new_from_file_at_scale (path, 16, 16, TRUE, NULL);
+      g_free (path);
+    }
+
+  return pixbuf;
+}
+#endif /* HAVE_ACCOUNTSSERVICE */
+
 static void
 create_user_combobox (PolkitMateAuthenticationDialog *dialog)
 {
-  int n;
+  int n, i, selected_index = 0;
   GtkComboBox *combo;
   GtkTreeIter iter;
   GtkCellRenderer *renderer;
@@ -162,11 +278,11 @@ create_user_combobox (PolkitMateAuthenticationDialog *dialog)
 
 
   /* For each user */
-  for (n = 0; dialog->priv->users[n] != NULL; n++)
-    {
+  for (i = 0, n = 0; dialog->priv->users[n] != NULL; n++)
+  {
       gchar *gecos;
       gchar *real_name;
-      GdkPixbuf *pixbuf;
+      GdkPixbuf *pixbuf = NULL;
       struct passwd *passwd;
 
       /* we're single threaded so this is fine */
@@ -197,15 +313,7 @@ create_user_combobox (PolkitMateAuthenticationDialog *dialog)
       g_free (gecos);
 
       /* Load users face */
-      pixbuf = NULL;
-      if (passwd->pw_dir != NULL)
-        {
-          gchar *path;
-          path = g_strdup_printf ("%s/.face", passwd->pw_dir);
-          /* TODO: we probably shouldn't hard-code the size to 16x16 */
-          pixbuf = gdk_pixbuf_new_from_file_at_scale (path, 16, 16, TRUE, NULL);
-          g_free (path);
-        }
+      pixbuf = get_user_icon (dialog->priv->users[n]);
 
       /* fall back to stock_person icon */
       if (pixbuf == NULL)
@@ -224,6 +332,14 @@ create_user_combobox (PolkitMateAuthenticationDialog *dialog)
                           USERNAME_COL, dialog->priv->users[n],
                           -1);
 
+      i++;
+      if (passwd->pw_uid == getuid ())
+        {
+          selected_index = i;
+          g_free (dialog->priv->selected_user);
+          dialog->priv->selected_user = g_strdup (dialog->priv->users[n]);
+        }
+
       g_free (real_name);
       g_object_unref (pixbuf);
     }
@@ -252,8 +368,8 @@ create_user_combobox (PolkitMateAuthenticationDialog *dialog)
                                       user_combobox_set_sensitive,
                                       NULL, NULL);
 
-  /* Initially select the "Select user..." ... */
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+  /* Select the default user */
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), selected_index);
 
   /* Listen when a new user is selected */
   g_signal_connect (GTK_WIDGET (combo),
@@ -561,6 +677,9 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
   g_free (s);
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtk_label_set_max_width_chars (GTK_LABEL (label), 50);
+#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), label, FALSE, FALSE, 0);
 
   /* secondary message */
@@ -588,6 +707,9 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
     }
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtk_label_set_max_width_chars (GTK_LABEL (label), 50);
+#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), label, FALSE, FALSE, 0);
 
   /* user combobox */
@@ -711,16 +833,13 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
   gtk_widget_set_tooltip_markup (label, s);
   g_free (s);
 
-  if (have_user_combobox)
+  /* Disable password entry and authenticate until have a user selected */
+  if (have_user_combobox && gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->user_combobox)) == 0)
     {
-      /* ... and make the password entry and "Authenticate" button insensitive */
       gtk_widget_set_sensitive (dialog->priv->prompt_label, FALSE);
       gtk_widget_set_sensitive (dialog->priv->password_entry, FALSE);
       gtk_widget_set_sensitive (dialog->priv->auth_button, FALSE);
     }
-  else
-    {
-    }
 
   gtk_widget_realize (GTK_WIDGET (dialog));
 
